@@ -76,11 +76,11 @@ class redundant_attachments extends filesystem_attachments
         }
 
         // Init SQL cache (disable cache data serialization)
-        $this->cache = $rcmail->get_cache($prefix, 'db', $ttl, false);
+        $this->cache = $rcmail->get_cache($prefix, 'db', $ttl, false, true);
 
         // Init memcache/redis (fallback) cache
         if ($fallback) {
-            $this->mem_cache = $rcmail->get_cache($prefix, $fallback, $ttl, false);
+            $this->mem_cache = $rcmail->get_cache($prefix, $fallback, $ttl, false, true);
         }
 
         $this->loaded = true;
@@ -91,7 +91,8 @@ class redundant_attachments extends filesystem_attachments
      */
     private function _key($args)
     {
-        $uname = $args['path'] ?: $args['name'];
+        $uname = !empty($args['path']) ? $args['path'] : $args['name'];
+
         return $args['group'] . md5(microtime() . $uname . $_SESSION['user_id']);
     }
 
@@ -107,10 +108,10 @@ class redundant_attachments extends filesystem_attachments
         $key  = $this->_key($args);
         $data = base64_encode(file_get_contents($args['path']));
 
-        $status = $this->cache->write($key, $data);
+        $status = $this->cache->set($key, $data);
 
         if (!$status && $this->mem_cache) {
-            $status = $this->mem_cache->write($key, $data);
+            $status = $this->mem_cache->set($key, $data);
         }
 
         if ($status) {
@@ -130,17 +131,17 @@ class redundant_attachments extends filesystem_attachments
 
         $this->_load_drivers();
 
-        $data = $args['path'] ? file_get_contents($args['path']) : $args['data'];
+        $data = !empty($args['path']) ? file_get_contents($args['path']) : $args['data'];
 
         $args['data'] = null;
 
         $key  = $this->_key($args);
         $data = base64_encode($data);
 
-        $status = $this->cache->write($key, $data);
+        $status = $this->cache->set($key, $data);
 
         if (!$status && $this->mem_cache) {
-            $status = $this->mem_cache->write($key, $data);
+            $status = $this->mem_cache->set($key, $data);
         }
 
         if ($status) {
@@ -193,17 +194,18 @@ class redundant_attachments extends filesystem_attachments
         // attempt to get file from local file system
         $args = parent::get($args);
 
-        if ($args['path'] && ($args['status'] = file_exists($args['path'])))
-          return $args;
+        if (!empty($args['path']) && ($args['status'] = file_exists($args['path']))) {
+            return $args;
+        }
 
         $this->_load_drivers();
 
         // fetch from database if not found on FS
-        $data = $this->cache->read($args['id']);
+        $data = $this->cache->get($args['id']);
 
         // fetch from memcache if not found on FS and DB
         if (($data === false || $data === null) && $this->mem_cache) {
-            $data = $this->mem_cache->read($args['id']);
+            $data = $this->mem_cache->get($args['id']);
         }
 
         if ($data) {
@@ -221,12 +223,14 @@ class redundant_attachments extends filesystem_attachments
     {
         $this->_load_drivers();
 
+        $group = $args['group'] ?? null;
+
         if ($this->cache) {
-            $this->cache->remove($args['group'], true);
+            $this->cache->remove($group, true);
         }
 
         if ($this->mem_cache) {
-            $this->mem_cache->remove($args['group'], true);
+            $this->mem_cache->remove($group, true);
         }
 
         parent::cleanup($args);
