@@ -1,10 +1,11 @@
 <?php
 
-/*
+/**
  +-----------------------------------------------------------------------+
  | This file is part of the Roundcube Webmail client                     |
- | Copyright (C) 2005-2011, The Roundcube Dev Team                       |
- | Copyright (C) 2011, Kolab Systems AG                                  |
+ |                                                                       |
+ | Copyright (C) The Roundcube Dev Team                                  |
+ | Copyright (C) Kolab Systems AG                                        |
  |                                                                       |
  | Licensed under the GNU General Public License version 3 or            |
  | any later version with exceptions for skins & plugins.                |
@@ -26,9 +27,11 @@
  */
 class rcube_result_thread
 {
+    public $incomplete = false;
+
     protected $raw_data;
     protected $mailbox;
-    protected $meta = array();
+    protected $meta  = [];
     protected $order = 'ASC';
 
     const SEPARATOR_ELEMENT = ' ';
@@ -45,7 +48,6 @@ class rcube_result_thread
         $this->init($data);
     }
 
-
     /**
      * Initializes object with IMAP command response
      *
@@ -53,12 +55,12 @@ class rcube_result_thread
      */
     public function init($data = null)
     {
-        $this->meta = array();
+        $this->meta = [];
 
-        $data = explode('*', (string)$data);
+        $data = explode('*', (string) $data);
 
         // ...skip unilateral untagged server responses
-        for ($i=0, $len=count($data); $i<$len; $i++) {
+        for ($i = 0, $len = count($data); $i < $len; $i++) {
             if (preg_match('/^ THREAD/i', $data[$i])) {
                 // valid response, initialize raw_data for is_error()
                 $this->raw_data = '';
@@ -73,15 +75,14 @@ class rcube_result_thread
             return;
         }
 
-        $data = array_shift($data);
+        $data = array_first($data);
         $data = trim($data);
         $data = preg_replace('/[\r\n]/', '', $data);
         $data = preg_replace('/\s+/', ' ', $data);
 
-        $this->raw_data = $this->parse_thread($data);
+        $this->raw_data = empty($data) ? '' : $this->parse_thread($data);
     }
 
-
     /**
      * Checks the result from IMAP command
      *
@@ -89,10 +90,9 @@ class rcube_result_thread
      */
     public function is_error()
     {
-        return $this->raw_data === null ? true : false;
+        return $this->raw_data === null;
     }
 
-
     /**
      * Checks if the result is empty
      *
@@ -100,10 +100,9 @@ class rcube_result_thread
      */
     public function is_empty()
     {
-        return empty($this->raw_data) ? true : false;
+        return empty($this->raw_data);
     }
 
-
     /**
      * Returns number of elements (threads) in the result
      *
@@ -111,8 +110,9 @@ class rcube_result_thread
      */
     public function count()
     {
-        if ($this->meta['count'] !== null)
+        if (isset($this->meta['count'])) {
             return $this->meta['count'];
+        }
 
         if (empty($this->raw_data)) {
             $this->meta['count'] = 0;
@@ -121,13 +121,13 @@ class rcube_result_thread
             $this->meta['count'] = 1 + substr_count($this->raw_data, self::SEPARATOR_ELEMENT);
         }
 
-        if (!$this->meta['count'])
+        if (!$this->meta['count']) {
             $this->meta['messages'] = 0;
+        }
 
         return $this->meta['count'];
     }
 
-
     /**
      * Returns number of all messages in the result
      *
@@ -135,8 +135,9 @@ class rcube_result_thread
      */
     public function count_messages()
     {
-        if ($this->meta['messages'] !== null)
+        if (isset($this->meta['messages'])) {
             return $this->meta['messages'];
+        }
 
         if (empty($this->raw_data)) {
             $this->meta['messages'] = 0;
@@ -147,58 +148,65 @@ class rcube_result_thread
                 + substr_count($this->raw_data, self::SEPARATOR_ITEM);
         }
 
-        if ($this->meta['messages'] == 0 || $this->meta['messages'] == 1)
+        if ($this->meta['messages'] == 0 || $this->meta['messages'] == 1) {
             $this->meta['count'] = $this->meta['messages'];
+        }
 
         return $this->meta['messages'];
     }
 
-
     /**
      * Returns maximum message identifier in the result
      *
-     * @return int Maximum message identifier
+     * @return int|null Maximum message identifier
      */
     public function max()
     {
+        if ($this->is_empty()) {
+            return null;
+        }
+
         if (!isset($this->meta['max'])) {
             $this->meta['max'] = (int) @max($this->get());
         }
+
         return $this->meta['max'];
     }
 
-
     /**
      * Returns minimum message identifier in the result
      *
-     * @return int Minimum message identifier
+     * @return int|null Minimum message identifier
      */
     public function min()
     {
+        if ($this->is_empty()) {
+            return null;
+        }
+
         if (!isset($this->meta['min'])) {
             $this->meta['min'] = (int) @min($this->get());
         }
+
         return $this->meta['min'];
     }
 
-
     /**
      * Slices data set.
      *
-     * @param $offset Offset (as for PHP's array_slice())
-     * @param $length Number of elements (as for PHP's array_slice())
+     * @param int $offset Offset (as for PHP's array_slice())
+     * @param int $length Number of elements (as for PHP's array_slice())
      */
     public function slice($offset, $length)
     {
         $data = explode(self::SEPARATOR_ELEMENT, $this->raw_data);
         $data = array_slice($data, $offset, $length);
 
-        $this->meta          = array();
+        $this->meta          = [];
         $this->meta['count'] = count($data);
         $this->raw_data      = implode(self::SEPARATOR_ELEMENT, $data);
     }
 
-
     /**
      * Filters data set. Removes threads not listed in $roots list.
      *
@@ -211,11 +219,11 @@ class rcube_result_thread
         $result  = '';
         $start   = 0;
 
-        $this->meta          = array();
-        $this->meta['count'] = 0;
+        $this->meta = ['count' => 0];
 
-        while (($pos = @strpos($this->raw_data, self::SEPARATOR_ELEMENT, $start))
-            || ($start < $datalen && ($pos = $datalen))
+        while ($start < $datalen
+            && (($pos = strpos($this->raw_data, self::SEPARATOR_ELEMENT, $start)) !== false
+                || ($pos = $datalen))
         ) {
             $len   = $pos - $start;
             $elem  = substr($this->raw_data, $start, $len);
@@ -238,7 +246,6 @@ class rcube_result_thread
         $this->raw_data = ltrim($result, self::SEPARATOR_ELEMENT);
     }
 
-
     /**
      * Reverts order of elements in the result
      */
@@ -250,25 +257,13 @@ class rcube_result_thread
             return;
         }
 
-        $this->meta['pos'] = array();
-        $datalen = strlen($this->raw_data);
-        $result  = '';
-        $start   = 0;
+        $data = explode(self::SEPARATOR_ELEMENT, $this->raw_data);
+        $data = array_reverse($data);
+        $this->raw_data = implode(self::SEPARATOR_ELEMENT, $data);
 
-        while (($pos = @strpos($this->raw_data, self::SEPARATOR_ELEMENT, $start))
-            || ($start < $datalen && ($pos = $datalen))
-        ) {
-            $len   = $pos - $start;
-            $elem  = substr($this->raw_data, $start, $len);
-            $start = $pos + 1;
-
-            $result = $elem . self::SEPARATOR_ELEMENT . $result;
-        }
-
-        $this->raw_data = rtrim($result, self::SEPARATOR_ELEMENT);
+        $this->meta['pos'] = [];
     }
 
-
     /**
      * Check if the given message ID exists in the object
      *
@@ -276,24 +271,24 @@ class rcube_result_thread
      * @param bool $get_index When enabled element's index will be returned.
      *                        Elements are indexed starting with 0
      *
-     * @return boolean True on success, False if message ID doesn't exist
+     * @return bool True on success, False if message ID doesn't exist
      */
     public function exists($msgid, $get_index = false)
     {
         $msgid = (int) $msgid;
-        $begin = implode('|', array(
+        $begin = implode('|', [
             '^',
             preg_quote(self::SEPARATOR_ELEMENT, '/'),
             preg_quote(self::SEPARATOR_LEVEL, '/'),
-        ));
-        $end = implode('|', array(
+        ]);
+        $end = implode('|', [
             '$',
             preg_quote(self::SEPARATOR_ELEMENT, '/'),
             preg_quote(self::SEPARATOR_ITEM, '/'),
-        ));
+        ]);
 
         if (preg_match("/($begin)$msgid($end)/", $this->raw_data, $m,
-            $get_index ? PREG_OFFSET_CAPTURE : null)
+            $get_index ? PREG_OFFSET_CAPTURE : 0)
         ) {
             if ($get_index) {
                 $idx = 0;
@@ -312,7 +307,6 @@ class rcube_result_thread
         return false;
     }
 
-
     /**
      * Return IDs of all messages in the result. Threaded data will be flattened.
      *
@@ -321,7 +315,7 @@ class rcube_result_thread
     public function get()
     {
         if (empty($this->raw_data)) {
-            return array();
+            return [];
         }
 
         $regexp = '/(' . preg_quote(self::SEPARATOR_ELEMENT, '/')
@@ -331,7 +325,6 @@ class rcube_result_thread
         return preg_split($regexp, $this->raw_data);
     }
 
-
     /**
      * Return all messages in the result.
      *
@@ -346,7 +339,6 @@ class rcube_result_thread
         return rcube_imap_generic::compressMessageSet($this->get());
     }
 
-
     /**
      * Return result element at specified index (all messages, not roots)
      *
@@ -383,16 +375,18 @@ class rcube_result_thread
             $regexp  = '(' . $element . '|' . $item . ')';
 
             if (isset($this->meta['pos'][$index])) {
-                if (preg_match('/([0-9]+)/', $this->raw_data, $m, null, $this->meta['pos'][$index]))
+                if (preg_match('/([0-9]+)/', $this->raw_data, $m, 0, $this->meta['pos'][$index])) {
                     $result = $m[1];
+                }
             }
             else if (isset($this->meta['pos'][$index-1])) {
                 // get chunk of data after previous element
                 $data = substr($this->raw_data, $this->meta['pos'][$index-1]+1, 50);
                 $data = preg_replace('/^[0-9]+/', '', $data); // remove UID at $index position
                 $data = preg_replace("/^$regexp/", '', $data); // remove separator
-                if (preg_match('/^([0-9]+)/', $data, $m))
+                if (preg_match('/^([0-9]+)/', $data, $m)) {
                     $result = $m[1];
+                }
             }
             else if (isset($this->meta['pos'][$index+1])) {
                 // get chunk of data before next element
@@ -401,8 +395,9 @@ class rcube_result_thread
                 $data = substr($this->raw_data, $pos, $len);
                 $data = preg_replace("/$regexp\$/", '', $data); // remove separator
 
-                if (preg_match('/([0-9]+)$/', $data, $m))
+                if (preg_match('/([0-9]+)$/', $data, $m)) {
                     $result = $m[1];
+                }
             }
 
             if (isset($result)) {
@@ -413,22 +408,22 @@ class rcube_result_thread
         // Finally use less effective method
         $data = $this->get();
 
-        return $data[$index];
+        return $data[$index] ?? null;
     }
 
-
     /**
      * Returns response parameters e.g. MAILBOX, ORDER
      *
-     * @param string $param  Parameter name
+     * @param string $param Parameter name
      *
      * @return array|string Response parameters or parameter value
      */
     public function get_parameters($param=null)
     {
-        $params = $this->params;
-        $params['MAILBOX'] = $this->mailbox;
-        $params['ORDER']   = $this->order;
+        $params = [
+            'MAILBOX' => $this->mailbox,
+            'ORDER'   => $this->order,
+        ];
 
         if ($param !== null) {
             return $params[$param];
@@ -437,15 +432,14 @@ class rcube_result_thread
         return $params;
     }
 
-
     /**
      * THREAD=REFS sorting implementation (based on provided index)
      *
-     * @param rcube_result_index $index  Sorted message identifiers
+     * @param rcube_result_index $index Sorted message identifiers
      */
     public function sort($index)
     {
-        $this->sort_order = $index->get_parameters('ORDER');
+        $this->order = $index->get_parameters('ORDER');
 
         if (empty($this->raw_data)) {
             return;
@@ -464,7 +458,8 @@ class rcube_result_thread
         // in memory at a time
 
         // Assign roots
-        while (($pos = @strpos($this->raw_data, self::SEPARATOR_ELEMENT, $start))
+        while (
+            ($start < $datalen && ($pos = strpos($this->raw_data, self::SEPARATOR_ELEMENT, $start)))
             || ($start < $datalen && ($pos = $datalen))
         ) {
             $len   = $pos - $start;
@@ -491,7 +486,8 @@ class rcube_result_thread
         $result = array_fill_keys($result, null);
         $start = 0;
 
-        while (($pos = @strpos($this->raw_data, self::SEPARATOR_ELEMENT, $start))
+        while (
+            ($start < $datalen && ($pos = strpos($this->raw_data, self::SEPARATOR_ELEMENT, $start)))
             || ($start < $datalen && ($pos = $datalen))
         ) {
             $len   = $pos - $start;
@@ -507,7 +503,6 @@ class rcube_result_thread
         $this->raw_data = implode(self::SEPARATOR_ELEMENT, $result);
     }
 
-
     /**
      * Returns data as tree
      *
@@ -516,11 +511,12 @@ class rcube_result_thread
     public function get_tree()
     {
         $datalen = strlen($this->raw_data);
-        $result  = array();
+        $result  = [];
         $start   = 0;
 
-        while (($pos = @strpos($this->raw_data, self::SEPARATOR_ELEMENT, $start))
-            || ($start < $datalen && ($pos = $datalen))
+        while ($start < $datalen
+            && (($pos = strpos($this->raw_data, self::SEPARATOR_ELEMENT, $start)) !== false
+                || ($pos = $datalen))
         ) {
             $len   = $pos - $start;
             $elem  = substr($this->raw_data, $start, $len);
@@ -532,7 +528,6 @@ class rcube_result_thread
         return $result;
     }
 
-
     /**
      * Returns thread depth and children data
      *
@@ -541,15 +536,14 @@ class rcube_result_thread
     public function get_thread_data()
     {
         $data     = $this->get_tree();
-        $depth    = array();
-        $children = array();
+        $depth    = [];
+        $children = [];
 
         $this->build_thread_data($data, $depth, $children);
 
-        return array($depth, $children);
+        return [$depth, $children];
     }
 
-
     /**
      * Creates 'depth' and 'children' arrays from stored thread 'tree' data.
      */
@@ -565,13 +559,12 @@ class rcube_result_thread
         }
     }
 
-
     /**
      * Converts part of the raw thread into an array
      */
     protected function build_thread($items, $level = 1, &$pos = 0)
     {
-        $result = array();
+        $result = [];
 
         for ($len=count($items); $pos < $len; $pos++) {
             list($lv, $id) = explode(self::SEPARATOR_LEVEL, $items[$pos]);
@@ -588,23 +581,22 @@ class rcube_result_thread
         return $result;
     }
 
-
     /**
      * IMAP THREAD response parser
      */
     protected function parse_thread($str, $begin = 0, $end = 0, $depth = 0)
     {
         // Don't be tempted to change $str to pass by reference to speed this up - it will slow it down by about
-        // 7 times instead :-) See comments on http://uk2.php.net/references and this article:
-        // http://derickrethans.nl/files/phparch-php-variables-article.pdf
+        // 7 times instead :-) See comments on https://www.php.net/references and this article:
+        // https://derickrethans.nl/files/phparch-php-variables-article.pdf
         $node = '';
         if (!$end) {
             $end = strlen($str);
         }
 
-        // Let's try to store data in max. compacted stracture as a string,
+        // Let's try to store data in max. compacted structure as a string,
         // arrays handling is much more expensive
-        // For the following structure: THREAD (2)(3 6 (4 23)(44 7 96))
+        // For the following structure: THREAD (2)(3 6 (4 23)(44 7 96))((11)(12))
         // -- 2
         // -- 3
         //     \-- 6
@@ -614,8 +606,11 @@ class rcube_result_thread
         //         \-- 44
         //               \-- 7
         //                    \-- 96
+        // -- 11
+        //      \-- 12
         //
-        // The output will be: 2,3^1:6^2:4^3:23^2:44^3:7^4:96
+        // The output will be: 2 3~1:6~2:4~3:23~2:44~3:7~4:96 11~1:12
+        // Note: The "11" thread has no root, we use the first message as root
 
         if ($str[$begin] != '(') {
             // find next bracket
@@ -629,7 +624,12 @@ class rcube_result_thread
             foreach ($messages as $msg) {
                 if ($msg) {
                     $node .= ($depth ? self::SEPARATOR_ITEM.$depth.self::SEPARATOR_LEVEL : '').$msg;
-                    $this->meta['messages']++;
+                    if (isset($this->meta['messages'])) {
+                        $this->meta['messages']++;
+                    }
+                    else {
+                        $this->meta['messages'] = 1;
+                    }
                     $depth++;
                 }
             }
@@ -651,6 +651,7 @@ class rcube_result_thread
                         // @TODO: write error to the log or maybe set $this->raw_data = null;
                         return $node;
                     }
+
                     $p1 = strpos($str, '(', $off);
                     if ($p1 !== false && $p1 < $p) {
                         $off = $p1 + 1;
@@ -662,7 +663,26 @@ class rcube_result_thread
                     }
                 }
 
-                $thread = $this->parse_thread($str, $start + 1, $off - 1, $depth);
+                // Handle threads with missing parent by using first message as root
+                if (substr_compare($str, '((', $start, 2) === 0) {
+                    // Extract the current thread, e.g. "((1)(2))"
+                    $thread = substr($str, $start, $off - $start);
+                    // Length of the first token, e.g. "(1)"
+                    $len = strspn($thread, '(0123456789', 1) + 1;
+                    // Extract the token and modify it to look like a thread root
+                    $token = substr($thread, 1, $len);
+                    // Warning: The order is important
+                    $token = str_replace('(', '', $token);
+                    $token = str_replace(' ', ' (', $token);
+                    $token = str_replace(')', ' ', $token);
+                    $thread  = substr_replace($thread, $token, 1, $len);
+                    // Parse the thread
+                    $thread = $this->parse_thread($thread, 0, 0, $depth);
+                }
+                else {
+                    $thread = $this->parse_thread($str, $start + 1, $off - 1, $depth);
+                }
+
                 if ($thread) {
                     if (!$depth) {
                         if ($node) {
